@@ -54,6 +54,8 @@ class Activity(models.Model):
     major_program_code = models.CharField(max_length=32)
     total_submitted = models.IntegerField()
     total_assigned = models.IntegerField()
+    assignment_category = models.CharField(max_length=32)
+    decision_import_id = models.IntegerField()
 
 
 class Application(models.Model):
